Slowsort

Trait Slowsort 

pub trait Slowsort {
    // Required method
    fn slowsort(&mut self);
}
This trait provides the slowsort functionality.

Required Methods

fn slowsort(&mut self)

Slowsort is a humurous sorting algorithm based on the principle of multiply and surrender. The algorithm itself is of recursive nature. It finds the maximum of the sorted array, places that maximum at the end and sorts the remaining array recursively.

A detailed explanation of Slowsort can be found on Wikipedia.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementations on Foreign Types

Source

impl<T: PartialOrd + Copy> Slowsort for Vec<T>

Source

fn slowsort(&mut self)

Implementors